pub type OnError = Box<dyn Fn(&Subscription, &Event) + Send + Sync + 'static>;Expand description
Boxed error callback, invoked once per handler that panics during
EventBus::emit.
Aliased Type
pub struct OnError(/* private fields */);pub type OnError = Box<dyn Fn(&Subscription, &Event) + Send + Sync + 'static>;Boxed error callback, invoked once per handler that panics during
EventBus::emit.
pub struct OnError(/* private fields */);